summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/asterisk/astobj2.h17
1 files changed, 12 insertions, 5 deletions
diff --git a/include/asterisk/astobj2.h b/include/asterisk/astobj2.h
index bc7a9f90f..70a9041c3 100644
--- a/include/asterisk/astobj2.h
+++ b/include/asterisk/astobj2.h
@@ -383,12 +383,19 @@ murf
/*! \brief
* Typedef for an object destructor. This is called just before freeing
* the memory for the object. It is passed a pointer to the user-defined
* data of the object.
*/
-typedef void (*ao2_destructor_fn)(void *);
+typedef void (*ao2_destructor_fn)(void *vdoomed);
/*! \brief Options available when allocating an ao2 object. */
enum ao2_alloc_opts {
@@ -383,12 +383,19 @@ murf
-/*! \brief
- * Typedef for an object destructor. This is called just before freeing
- * the memory for the object. It is passed a pointer to the user-defined
- * data of the object.
+/*!
+ * \brief Typedef for an object destructor.
+ *
+ * \param vdoomed Object to destroy.
+ *
+ * \details
+ * This is called just before freeing the memory for the object.
+ * It is passed a pointer to the user-defined data of the
+ * object.
+ *
+ * \return Nothing
*/